==> google_cloud_discoveryengine-0.11.14-py3-none-any.whl: google/cloud/discoveryengine_v1alpha/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .acl_config import AclConfig
from .acl_config_service import GetAclConfigRequest, UpdateAclConfigRequest
from .answer import Answer
from .chunk import Chunk
from .chunk_service import GetChunkRequest, ListChunksRequest, ListChunksResponse
from .common import (
    CustomAttribute,
    CustomFineTuningSpec,
    DoubleList,
    EmbeddingConfig,
    GuidedSearchSpec,
    IdpConfig,
    IndustryVertical,
    Interval,
    Principal,
    SearchAddOn,
    SearchTier,
    SearchUseCase,
    SolutionType,
    UserInfo,
)
from .completion import SuggestionDenyListEntry
from .completion_service import CompleteQueryRequest, CompleteQueryResponse
from .control import Condition, Control
from .control_service import (
    CreateControlRequest,
    DeleteControlRequest,
    GetControlRequest,
    ListControlsRequest,
    ListControlsResponse,
    UpdateControlRequest,
)
from .conversation import (
    Conversation,
    ConversationContext,
    ConversationMessage,
    Reply,
    TextInput,
)
from .conversational_search_service import (
    AnswerQueryRequest,
    AnswerQueryResponse,
    ConverseConversationRequest,
    ConverseConversationResponse,
    CreateConversationRequest,
    CreateSessionRequest,
    DeleteConversationRequest,
    DeleteSessionRequest,
    GetAnswerRequest,
    GetConversationRequest,
    GetSessionRequest,
    ListConversationsRequest,
    ListConversationsResponse,
    ListSessionsRequest,
    ListSessionsResponse,
    UpdateConversationRequest,
    UpdateSessionRequest,
)
from .custom_tuning_model import CustomTuningModel
from .data_store import DataStore
from .data_store_service import (
    CreateDataStoreMetadata,
    CreateDataStoreRequest,
    DeleteDataStoreMetadata,
    DeleteDataStoreRequest,
    GetDataStoreRequest,
    GetDocumentProcessingConfigRequest,
    ListDataStoresRequest,
    ListDataStoresResponse,
    UpdateDataStoreRequest,
    UpdateDocumentProcessingConfigRequest,
)
from .document import Document, ProcessedDocument
from .document_processing_config import DocumentProcessingConfig
from .document_service import (
    CreateDocumentRequest,
    DeleteDocumentRequest,
    GetDocumentRequest,
    GetProcessedDocumentRequest,
    ListDocumentsRequest,
    ListDocumentsResponse,
    UpdateDocumentRequest,
)
from .engine import Engine
from .engine_service import (
    CreateEngineMetadata,
    CreateEngineRequest,
    DeleteEngineMetadata,
    DeleteEngineRequest,
    GetEngineRequest,
    ListEnginesRequest,
    ListEnginesResponse,
    PauseEngineRequest,
    ResumeEngineRequest,
    TuneEngineMetadata,
    TuneEngineRequest,
    TuneEngineResponse,
    UpdateEngineRequest,
)
from .estimate_billing_service import (
    EstimateDataSizeMetadata,
    EstimateDataSizeRequest,
    EstimateDataSizeResponse,
)
from .grounded_generation_service import (
    CheckGroundingRequest,
    CheckGroundingResponse,
    CheckGroundingSpec,
)
from .grounding import FactChunk, GroundingFact
from .import_config import (
    BigQuerySource,
    BigtableOptions,
    BigtableSource,
    CloudSqlSource,
    FhirStoreSource,
    FirestoreSource,
    GcsSource,
    ImportDocumentsMetadata,
    ImportDocumentsRequest,
    ImportDocumentsResponse,
    ImportErrorConfig,
    ImportSuggestionDenyListEntriesMetadata,
    ImportSuggestionDenyListEntriesRequest,
    ImportSuggestionDenyListEntriesResponse,
    ImportUserEventsMetadata,
    ImportUserEventsRequest,
    ImportUserEventsResponse,
    SpannerSource,
)
from .project import Project
from .project_service import (
    GetProjectRequest,
    ProvisionProjectMetadata,
    ProvisionProjectRequest,
    ReportConsentChangeRequest,
)
from .purge_config import (
    PurgeDocumentsMetadata,
    PurgeDocumentsRequest,
    PurgeDocumentsResponse,
    PurgeErrorConfig,
    PurgeSuggestionDenyListEntriesMetadata,
    PurgeSuggestionDenyListEntriesRequest,
    PurgeSuggestionDenyListEntriesResponse,
    PurgeUserEventsMetadata,
    PurgeUserEventsRequest,
    PurgeUserEventsResponse,
)
from .rank_service import RankingRecord, RankRequest, RankResponse
from .recommendation_service import RecommendRequest, RecommendResponse
from .schema import FieldConfig, Schema
from .schema_service import (
    CreateSchemaMetadata,
    CreateSchemaRequest,
    DeleteSchemaMetadata,
    DeleteSchemaRequest,
    GetSchemaRequest,
    ListSchemasRequest,
    ListSchemasResponse,
    UpdateSchemaMetadata,
    UpdateSchemaRequest,
)
from .search_service import SearchRequest, SearchResponse
from .search_tuning_service import (
    ListCustomModelsRequest,
    ListCustomModelsResponse,
    TrainCustomModelMetadata,
    TrainCustomModelRequest,
    TrainCustomModelResponse,
)
from .serving_config import ServingConfig
from .serving_config_service import (
    GetServingConfigRequest,
    ListServingConfigsRequest,
    ListServingConfigsResponse,
    UpdateServingConfigRequest,
)
from .session import Query, Session
from .site_search_engine import SiteSearchEngine, SiteVerificationInfo, TargetSite
from .site_search_engine_service import (
    BatchCreateTargetSiteMetadata,
    BatchCreateTargetSitesRequest,
    BatchCreateTargetSitesResponse,
    BatchVerifyTargetSitesMetadata,
    BatchVerifyTargetSitesRequest,
    BatchVerifyTargetSitesResponse,
    CreateTargetSiteMetadata,
    CreateTargetSiteRequest,
    DeleteTargetSiteMetadata,
    DeleteTargetSiteRequest,
    DisableAdvancedSiteSearchMetadata,
    DisableAdvancedSiteSearchRequest,
    DisableAdvancedSiteSearchResponse,
    EnableAdvancedSiteSearchMetadata,
    EnableAdvancedSiteSearchRequest,
    EnableAdvancedSiteSearchResponse,
    FetchDomainVerificationStatusRequest,
    FetchDomainVerificationStatusResponse,
    GetSiteSearchEngineRequest,
    GetTargetSiteRequest,
    ListTargetSitesRequest,
    ListTargetSitesResponse,
    RecrawlUrisMetadata,
    RecrawlUrisRequest,
    RecrawlUrisResponse,
    UpdateTargetSiteMetadata,
    UpdateTargetSiteRequest,
)
from .user_event import (
    CompletionInfo,
    DocumentInfo,
    MediaInfo,
    PageInfo,
    PanelInfo,
    SearchInfo,
    TransactionInfo,
    UserEvent,
)
from .user_event_service import CollectUserEventRequest, WriteUserEventRequest

__all__ = (
    "AclConfig",
    "GetAclConfigRequest",
    "UpdateAclConfigRequest",
    "Answer",
    "Chunk",
    "GetChunkRequest",
    "ListChunksRequest",
    "ListChunksResponse",
    "CustomAttribute",
    "CustomFineTuningSpec",
    "DoubleList",
    "EmbeddingConfig",
    "GuidedSearchSpec",
    "IdpConfig",
    "Interval",
    "Principal",
    "UserInfo",
    "IndustryVertical",
    "SearchAddOn",
    "SearchTier",
    "SearchUseCase",
    "SolutionType",
    "SuggestionDenyListEntry",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "Condition",
    "Control",
    "CreateControlRequest",
    "DeleteControlRequest",
    "GetControlRequest",
    "ListControlsRequest",
    "ListControlsResponse",
    "UpdateControlRequest",
    "Conversation",
    "ConversationContext",
    "ConversationMessage",
    "Reply",
    "TextInput",
    "AnswerQueryRequest",
    "AnswerQueryResponse",
    "ConverseConversationRequest",
    "ConverseConversationResponse",
    "CreateConversationRequest",
    "CreateSessionRequest",
    "DeleteConversationRequest",
    "DeleteSessionRequest",
    "GetAnswerRequest",
    "GetConversationRequest",
    "GetSessionRequest",
    "ListConversationsRequest",
    "ListConversationsResponse",
    "ListSessionsRequest",
    "ListSessionsResponse",
    "UpdateConversationRequest",
    "UpdateSessionRequest",
    "CustomTuningModel",
    "DataStore",
    "CreateDataStoreMetadata",
    "CreateDataStoreRequest",
    "DeleteDataStoreMetadata",
    "DeleteDataStoreRequest",
    "GetDataStoreRequest",
    "GetDocumentProcessingConfigRequest",
    "ListDataStoresRequest",
    "ListDataStoresResponse",
    "UpdateDataStoreRequest",
    "UpdateDocumentProcessingConfigRequest",
    "Document",
    "ProcessedDocument",
    "DocumentProcessingConfig",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "GetDocumentRequest",
    "GetProcessedDocumentRequest",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "UpdateDocumentRequest",
    "Engine",
    "CreateEngineMetadata",
    "CreateEngineRequest",
    "DeleteEngineMetadata",
    "DeleteEngineRequest",
    "GetEngineRequest",
    "ListEnginesRequest",
    "ListEnginesResponse",
    "PauseEngineRequest",
    "ResumeEngineRequest",
    "TuneEngineMetadata",
    "TuneEngineRequest",
    "TuneEngineResponse",
    "UpdateEngineRequest",
    "EstimateDataSizeMetadata",
    "EstimateDataSizeRequest",
    "EstimateDataSizeResponse",
    "CheckGroundingRequest",
    "CheckGroundingResponse",
    "CheckGroundingSpec",
    "FactChunk",
    "GroundingFact",
    "BigQuerySource",
    "BigtableOptions",
    "BigtableSource",
    "CloudSqlSource",
    "FhirStoreSource",
    "FirestoreSource",
    "GcsSource",
    "ImportDocumentsMetadata",
    "ImportDocumentsRequest",
    "ImportDocumentsResponse",
    "ImportErrorConfig",
    "ImportSuggestionDenyListEntriesMetadata",
    "ImportSuggestionDenyListEntriesRequest",
    "ImportSuggestionDenyListEntriesResponse",
    "ImportUserEventsMetadata",
    "ImportUserEventsRequest",
    "ImportUserEventsResponse",
    "SpannerSource",
    "Project",
    "GetProjectRequest",
    "ProvisionProjectMetadata",
    "ProvisionProjectRequest",
    "ReportConsentChangeRequest",
    "PurgeDocumentsMetadata",
    "PurgeDocumentsRequest",
    "PurgeDocumentsResponse",
    "PurgeErrorConfig",
    "PurgeSuggestionDenyListEntriesMetadata",
    "PurgeSuggestionDenyListEntriesRequest",
    "PurgeSuggestionDenyListEntriesResponse",
    "PurgeUserEventsMetadata",
    "PurgeUserEventsRequest",
    "PurgeUserEventsResponse",
    "RankingRecord",
    "RankRequest",
    "RankResponse",
    "RecommendRequest",
    "RecommendResponse",
    "FieldConfig",
    "Schema",
    "CreateSchemaMetadata",
    "CreateSchemaRequest",
    "DeleteSchemaMetadata",
    "DeleteSchemaRequest",
    "GetSchemaRequest",
    "ListSchemasRequest",
    "ListSchemasResponse",
    "UpdateSchemaMetadata",
    "UpdateSchemaRequest",
    "SearchRequest",
    "SearchResponse",
    "ListCustomModelsRequest",
    "ListCustomModelsResponse",
    "TrainCustomModelMetadata",
    "TrainCustomModelRequest",
    "TrainCustomModelResponse",
    "ServingConfig",
    "GetServingConfigRequest",
    "ListServingConfigsRequest",
    "ListServingConfigsResponse",
    "UpdateServingConfigRequest",
    "Query",
    "Session",
    "SiteSearchEngine",
    "SiteVerificationInfo",
    "TargetSite",
    "BatchCreateTargetSiteMetadata",
    "BatchCreateTargetSitesRequest",
    "BatchCreateTargetSitesResponse",
    "BatchVerifyTargetSitesMetadata",
    "BatchVerifyTargetSitesRequest",
    "BatchVerifyTargetSitesResponse",
    "CreateTargetSiteMetadata",
    "CreateTargetSiteRequest",
    "DeleteTargetSiteMetadata",
    "DeleteTargetSiteRequest",
    "DisableAdvancedSiteSearchMetadata",
    "DisableAdvancedSiteSearchRequest",
    "DisableAdvancedSiteSearchResponse",
    "EnableAdvancedSiteSearchMetadata",
    "EnableAdvancedSiteSearchRequest",
    "EnableAdvancedSiteSearchResponse",
    "FetchDomainVerificationStatusRequest",
    "FetchDomainVerificationStatusResponse",
    "GetSiteSearchEngineRequest",
    "GetTargetSiteRequest",
    "ListTargetSitesRequest",
    "ListTargetSitesResponse",
    "RecrawlUrisMetadata",
    "RecrawlUrisRequest",
    "RecrawlUrisResponse",
    "UpdateTargetSiteMetadata",
    "UpdateTargetSiteRequest",
    "CompletionInfo",
    "DocumentInfo",
    "MediaInfo",
    "PageInfo",
    "PanelInfo",
    "SearchInfo",
    "TransactionInfo",
    "UserEvent",
    "CollectUserEventRequest",
    "WriteUserEventRequest",
)

==> google_cloud_discoveryengine-0.12.0-py3-none-any.whl: google/cloud/discoveryengine_v1alpha/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .acl_config import AclConfig
from .acl_config_service import GetAclConfigRequest, UpdateAclConfigRequest
from .answer import Answer
from .chunk import Chunk
from .chunk_service import GetChunkRequest, ListChunksRequest, ListChunksResponse
from .common import (
    CustomAttribute,
    CustomFineTuningSpec,
    DoubleList,
    EmbeddingConfig,
    GuidedSearchSpec,
    IdpConfig,
    IndustryVertical,
    Interval,
    Principal,
    SearchAddOn,
    SearchTier,
    SearchUseCase,
    SolutionType,
    UserInfo,
)
from .completion import SuggestionDenyListEntry
from .completion_service import CompleteQueryRequest, CompleteQueryResponse
from .control import Condition, Control
from .control_service import (
    CreateControlRequest,
    DeleteControlRequest,
    GetControlRequest,
    ListControlsRequest,
    ListControlsResponse,
    UpdateControlRequest,
)
from .conversation import (
    Conversation,
    ConversationContext,
    ConversationMessage,
    Reply,
    TextInput,
)
from .conversational_search_service import (
    AnswerQueryRequest,
    AnswerQueryResponse,
    ConverseConversationRequest,
    ConverseConversationResponse,
    CreateConversationRequest,
    CreateSessionRequest,
    DeleteConversationRequest,
    DeleteSessionRequest,
    GetAnswerRequest,
    GetConversationRequest,
    GetSessionRequest,
    ListConversationsRequest,
    ListConversationsResponse,
    ListSessionsRequest,
    ListSessionsResponse,
    UpdateConversationRequest,
    UpdateSessionRequest,
)
from .custom_tuning_model import CustomTuningModel
from .data_store import DataStore
from .data_store_service import (
    CreateDataStoreMetadata,
    CreateDataStoreRequest,
    DeleteDataStoreMetadata,
    DeleteDataStoreRequest,
    GetDataStoreRequest,
    GetDocumentProcessingConfigRequest,
    ListDataStoresRequest,
    ListDataStoresResponse,
    UpdateDataStoreRequest,
    UpdateDocumentProcessingConfigRequest,
)
from .document import Document, ProcessedDocument
from .document_processing_config import DocumentProcessingConfig
from .document_service import (
    CreateDocumentRequest,
    DeleteDocumentRequest,
    GetDocumentRequest,
    GetProcessedDocumentRequest,
    ListDocumentsRequest,
    ListDocumentsResponse,
    UpdateDocumentRequest,
)
from .engine import Engine
from .engine_service import (
    CreateEngineMetadata,
    CreateEngineRequest,
    DeleteEngineMetadata,
    DeleteEngineRequest,
    GetEngineRequest,
    ListEnginesRequest,
    ListEnginesResponse,
    PauseEngineRequest,
    ResumeEngineRequest,
    TuneEngineMetadata,
    TuneEngineRequest,
    TuneEngineResponse,
    UpdateEngineRequest,
)
from .estimate_billing_service import (
    EstimateDataSizeMetadata,
    EstimateDataSizeRequest,
    EstimateDataSizeResponse,
)
from .evaluation import Evaluation, QualityMetrics
from .evaluation_service import (
    CreateEvaluationMetadata,
    CreateEvaluationRequest,
    GetEvaluationRequest,
    ListEvaluationResultsRequest,
    ListEvaluationResultsResponse,
    ListEvaluationsRequest,
    ListEvaluationsResponse,
)
from .grounded_generation_service import (
    CheckGroundingRequest,
    CheckGroundingResponse,
    CheckGroundingSpec,
)
from .grounding import FactChunk, GroundingFact
from .import_config import (
    BigQuerySource,
    BigtableOptions,
    BigtableSource,
    CloudSqlSource,
    FhirStoreSource,
    FirestoreSource,
    GcsSource,
    ImportDocumentsMetadata,
    ImportDocumentsRequest,
    ImportDocumentsResponse,
    ImportErrorConfig,
    ImportSampleQueriesMetadata,
    ImportSampleQueriesRequest,
    ImportSampleQueriesResponse,
    ImportSuggestionDenyListEntriesMetadata,
    ImportSuggestionDenyListEntriesRequest,
    ImportSuggestionDenyListEntriesResponse,
    ImportUserEventsMetadata,
    ImportUserEventsRequest,
    ImportUserEventsResponse,
    SpannerSource,
)
from .project import Project
from .project_service import (
    GetProjectRequest,
    ProvisionProjectMetadata,
    ProvisionProjectRequest,
    ReportConsentChangeRequest,
)
from .purge_config import (
    PurgeDocumentsMetadata,
    PurgeDocumentsRequest,
    PurgeDocumentsResponse,
    PurgeErrorConfig,
    PurgeSuggestionDenyListEntriesMetadata,
    PurgeSuggestionDenyListEntriesRequest,
    PurgeSuggestionDenyListEntriesResponse,
    PurgeUserEventsMetadata,
    PurgeUserEventsRequest,
    PurgeUserEventsResponse,
)
from .rank_service import RankingRecord, RankRequest, RankResponse
from .recommendation_service import RecommendRequest, RecommendResponse
from .sample_query import SampleQuery
from .sample_query_service import (
    CreateSampleQueryRequest,
    DeleteSampleQueryRequest,
    GetSampleQueryRequest,
    ListSampleQueriesRequest,
    ListSampleQueriesResponse,
    UpdateSampleQueryRequest,
)
from .sample_query_set import SampleQuerySet
from .sample_query_set_service import (
    CreateSampleQuerySetRequest,
    DeleteSampleQuerySetRequest,
    GetSampleQuerySetRequest,
    ListSampleQuerySetsRequest,
    ListSampleQuerySetsResponse,
    UpdateSampleQuerySetRequest,
)
from .schema import FieldConfig, Schema
from .schema_service import (
    CreateSchemaMetadata,
    CreateSchemaRequest,
    DeleteSchemaMetadata,
    DeleteSchemaRequest,
    GetSchemaRequest,
    ListSchemasRequest,
    ListSchemasResponse,
    UpdateSchemaMetadata,
    UpdateSchemaRequest,
)
from .search_service import SearchRequest, SearchResponse
from .search_tuning_service import (
    ListCustomModelsRequest,
    ListCustomModelsResponse,
    TrainCustomModelMetadata,
    TrainCustomModelRequest,
    TrainCustomModelResponse,
)
from .serving_config import ServingConfig
from .serving_config_service import (
    GetServingConfigRequest,
    ListServingConfigsRequest,
    ListServingConfigsResponse,
    UpdateServingConfigRequest,
)
from .session import Query, Session
from .site_search_engine import SiteSearchEngine, SiteVerificationInfo, TargetSite
from .site_search_engine_service import (
    BatchCreateTargetSiteMetadata,
    BatchCreateTargetSitesRequest,
    BatchCreateTargetSitesResponse,
    BatchVerifyTargetSitesMetadata,
    BatchVerifyTargetSitesRequest,
    BatchVerifyTargetSitesResponse,
    CreateTargetSiteMetadata,
    CreateTargetSiteRequest,
    DeleteTargetSiteMetadata,
    DeleteTargetSiteRequest,
    DisableAdvancedSiteSearchMetadata,
    DisableAdvancedSiteSearchRequest,
    DisableAdvancedSiteSearchResponse,
    EnableAdvancedSiteSearchMetadata,
    EnableAdvancedSiteSearchRequest,
    EnableAdvancedSiteSearchResponse,
    FetchDomainVerificationStatusRequest,
    FetchDomainVerificationStatusResponse,
    GetSiteSearchEngineRequest,
    GetTargetSiteRequest,
    ListTargetSitesRequest,
    ListTargetSitesResponse,
    RecrawlUrisMetadata,
    RecrawlUrisRequest,
    RecrawlUrisResponse,
    UpdateTargetSiteMetadata,
    UpdateTargetSiteRequest,
)
from .user_event import (
    CompletionInfo,
    DocumentInfo,
    MediaInfo,
    PageInfo,
    PanelInfo,
    SearchInfo,
    TransactionInfo,
    UserEvent,
)
from .user_event_service import CollectUserEventRequest, WriteUserEventRequest

__all__ = (
    "AclConfig",
    "GetAclConfigRequest",
    "UpdateAclConfigRequest",
    "Answer",
    "Chunk",
    "GetChunkRequest",
    "ListChunksRequest",
    "ListChunksResponse",
    "CustomAttribute",
    "CustomFineTuningSpec",
    "DoubleList",
    "EmbeddingConfig",
    "GuidedSearchSpec",
    "IdpConfig",
    "Interval",
    "Principal",
    "UserInfo",
    "IndustryVertical",
    "SearchAddOn",
    "SearchTier",
    "SearchUseCase",
    "SolutionType",
    "SuggestionDenyListEntry",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "Condition",
    "Control",
    "CreateControlRequest",
    "DeleteControlRequest",
    "GetControlRequest",
    "ListControlsRequest",
    "ListControlsResponse",
    "UpdateControlRequest",
    "Conversation",
    "ConversationContext",
    "ConversationMessage",
    "Reply",
    "TextInput",
    "AnswerQueryRequest",
    "AnswerQueryResponse",
    "ConverseConversationRequest",
    "ConverseConversationResponse",
    "CreateConversationRequest",
    "CreateSessionRequest",
    "DeleteConversationRequest",
    "DeleteSessionRequest",
    "GetAnswerRequest",
    "GetConversationRequest",
    "GetSessionRequest",
    "ListConversationsRequest",
    "ListConversationsResponse",
    "ListSessionsRequest",
    "ListSessionsResponse",
    "UpdateConversationRequest",
    "UpdateSessionRequest",
    "CustomTuningModel",
    "DataStore",
    "CreateDataStoreMetadata",
    "CreateDataStoreRequest",
    "DeleteDataStoreMetadata",
    "DeleteDataStoreRequest",
    "GetDataStoreRequest",
    "GetDocumentProcessingConfigRequest",
    "ListDataStoresRequest",
    "ListDataStoresResponse",
    "UpdateDataStoreRequest",
    "UpdateDocumentProcessingConfigRequest",
    "Document",
    "ProcessedDocument",
    "DocumentProcessingConfig",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "GetDocumentRequest",
    "GetProcessedDocumentRequest",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "UpdateDocumentRequest",
    "Engine",
    "CreateEngineMetadata",
    "CreateEngineRequest",
    "DeleteEngineMetadata",
    "DeleteEngineRequest",
    "GetEngineRequest",
    "ListEnginesRequest",
    "ListEnginesResponse",
    "PauseEngineRequest",
    "ResumeEngineRequest",
    "TuneEngineMetadata",
    "TuneEngineRequest",
    "TuneEngineResponse",
    "UpdateEngineRequest",
    "EstimateDataSizeMetadata",
    "EstimateDataSizeRequest",
    "EstimateDataSizeResponse",
    "Evaluation",
    "QualityMetrics",
    "CreateEvaluationMetadata",
    "CreateEvaluationRequest",
    "GetEvaluationRequest",
    "ListEvaluationResultsRequest",
    "ListEvaluationResultsResponse",
    "ListEvaluationsRequest",
    "ListEvaluationsResponse",
    "CheckGroundingRequest",
    "CheckGroundingResponse",
    "CheckGroundingSpec",
    "FactChunk",
    "GroundingFact",
    "BigQuerySource",
    "BigtableOptions",
    "BigtableSource",
    "CloudSqlSource",
    "FhirStoreSource",
    "FirestoreSource",
    "GcsSource",
    "ImportDocumentsMetadata",
    "ImportDocumentsRequest",
    "ImportDocumentsResponse",
    "ImportErrorConfig",
    "ImportSampleQueriesMetadata",
    "ImportSampleQueriesRequest",
    "ImportSampleQueriesResponse",
    "ImportSuggestionDenyListEntriesMetadata",
    "ImportSuggestionDenyListEntriesRequest",
    "ImportSuggestionDenyListEntriesResponse",
    "ImportUserEventsMetadata",
    "ImportUserEventsRequest",
    "ImportUserEventsResponse",
    "SpannerSource",
    "Project",
    "GetProjectRequest",
    "ProvisionProjectMetadata",
    "ProvisionProjectRequest",
    "ReportConsentChangeRequest",
    "PurgeDocumentsMetadata",
    "PurgeDocumentsRequest",
    "PurgeDocumentsResponse",
    "PurgeErrorConfig",
    "PurgeSuggestionDenyListEntriesMetadata",
    "PurgeSuggestionDenyListEntriesRequest",
    "PurgeSuggestionDenyListEntriesResponse",
    "PurgeUserEventsMetadata",
    "PurgeUserEventsRequest",
    "PurgeUserEventsResponse",
    "RankingRecord",
    "RankRequest",
    "RankResponse",
    "RecommendRequest",
    "RecommendResponse",
    "SampleQuery",
    "CreateSampleQueryRequest",
    "DeleteSampleQueryRequest",
    "GetSampleQueryRequest",
    "ListSampleQueriesRequest",
    "ListSampleQueriesResponse",
    "UpdateSampleQueryRequest",
    "SampleQuerySet",
    "CreateSampleQuerySetRequest",
    "DeleteSampleQuerySetRequest",
    "GetSampleQuerySetRequest",
    "ListSampleQuerySetsRequest",
    "ListSampleQuerySetsResponse",
    "UpdateSampleQuerySetRequest",
    "FieldConfig",
    "Schema",
    "CreateSchemaMetadata",
    "CreateSchemaRequest",
    "DeleteSchemaMetadata",
    "DeleteSchemaRequest",
    "GetSchemaRequest",
    "ListSchemasRequest",
    "ListSchemasResponse",
    "UpdateSchemaMetadata",
    "UpdateSchemaRequest",
    "SearchRequest",
    "SearchResponse",
    "ListCustomModelsRequest",
    "ListCustomModelsResponse",
    "TrainCustomModelMetadata",
    "TrainCustomModelRequest",
    "TrainCustomModelResponse",
    "ServingConfig",
    "GetServingConfigRequest",
    "ListServingConfigsRequest",
    "ListServingConfigsResponse",
    "UpdateServingConfigRequest",
    "Query",
    "Session",
    "SiteSearchEngine",
    "SiteVerificationInfo",
    "TargetSite",
    "BatchCreateTargetSiteMetadata",
    "BatchCreateTargetSitesRequest",
    "BatchCreateTargetSitesResponse",
    "BatchVerifyTargetSitesMetadata",
    "BatchVerifyTargetSitesRequest",
    "BatchVerifyTargetSitesResponse",
    "CreateTargetSiteMetadata",
    "CreateTargetSiteRequest",
    "DeleteTargetSiteMetadata",
    "DeleteTargetSiteRequest",
    "DisableAdvancedSiteSearchMetadata",
    "DisableAdvancedSiteSearchRequest",
    "DisableAdvancedSiteSearchResponse",
    "EnableAdvancedSiteSearchMetadata",
    "EnableAdvancedSiteSearchRequest",
    "EnableAdvancedSiteSearchResponse",
    "FetchDomainVerificationStatusRequest",
    "FetchDomainVerificationStatusResponse",
    "GetSiteSearchEngineRequest",
    "GetTargetSiteRequest",
    "ListTargetSitesRequest",
    "ListTargetSitesResponse",
    "RecrawlUrisMetadata",
    "RecrawlUrisRequest",
    "RecrawlUrisResponse",
    "UpdateTargetSiteMetadata",
    "UpdateTargetSiteRequest",
    "CompletionInfo",
    "DocumentInfo",
    "MediaInfo",
    "PageInfo",
    "PanelInfo",
    "SearchInfo",
    "TransactionInfo",
    "UserEvent",
    "CollectUserEventRequest",
    "WriteUserEventRequest",
)
